ace: ACE Richness Estimator

View source: R/estimators.R

aceR Documentation

ACE Richness Estimator

Description

Abundance-based Coverage Estimator (ACE) of total species richness (Chao & Lee 1992). Separates species into rare and abundant groups based on an abundance threshold.

Usage

ace(x, threshold = 10L)

Arguments

x

A site-by-species matrix (abundance data).

threshold

Integer. Abundance threshold separating rare from abundant species. Default 10.

Details

ACE partitions species into rare (abundance \le threshold) and abundant (abundance > threshold) groups. The estimate is:

S_{ACE} = S_{abund} + \frac{S_{rare}}{C_{ACE}} + \frac{f_1}{C_{ACE}} \gamma^2

where C_{ACE} is the sample coverage of rare species and \gamma^2 is the estimated coefficient of variation.

Value

An object of class spacc_estimate.

References

Chao, A. & Lee, S.M. (1992). Estimating the number of classes via sample coverage. Journal of the American Statistical Association, 87, 210-217.

See Also

chao1(), chao2()

Examples

species <- matrix(rpois(50 * 30, 2), nrow = 50)
ace(species)


spacc documentation built on June 20, 2026, 5:07 p.m.