| dar | R Documentation |
Extend the classic species-area relationship (SAR) to a diversity-area relationship using Hill numbers of any order q. Instead of plotting species richness vs. sites, this plots effective diversity vs. cumulative area.
dar(
x,
coords,
q = c(0, 1, 2),
n_seeds = 50L,
method = "knn",
area_method = c("convex_hull", "voronoi", "count"),
distance = c("euclidean", "haversine"),
parallel = TRUE,
n_cores = NULL,
progress = TRUE,
seed = NULL
)
x |
A site-by-species matrix (abundance data recommended). |
coords |
A data.frame with columns |
q |
Numeric vector. Diversity orders. Default |
n_seeds |
Integer. Number of random starting points. Default 50. |
method |
Character. Accumulation method. Default |
area_method |
Character. How to estimate cumulative area:
|
distance |
Character. Distance method. Default |
parallel |
Logical. Use parallel processing? Default |
n_cores |
Integer. Number of cores. |
progress |
Logical. Show progress? Default |
seed |
Integer. Random seed. |
The DAR (Ma, 2018) generalizes the SAR by replacing species richness (q=0) with Hill numbers of any order. This reveals how different facets of diversity scale with area:
q=0 (richness) recovers the classic SAR
q=1 (Shannon) shows how common species diversity scales
q=2 (Simpson) shows how dominant species diversity scales
An object of class spacc_dar containing:
hill |
A |
area |
Matrix of cumulative areas (n_seeds x n_sites) |
q |
Diversity orders used |
area_method |
Method used for area estimation |
Ma, Z.S. (2018). DAR (diversity-area relationship): extending classic SAR for biodiversity and biogeography analyses. Ecology and Evolution, 8, 10023-10038.
Arrhenius, O. (1921). Species and area. Journal of Ecology, 9, 95-99.
spaccHill(), extrapolate()
coords <- data.frame(x = runif(50), y = runif(50))
species <- matrix(rpois(50 * 30, 2), nrow = 50)
dar <- dar(species, coords, q = c(0, 1, 2))
plot(dar)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.