| extrapolate | R Documentation |
Fit an asymptotic model to estimate total species richness beyond the observed sampling effort.
extrapolate(
object,
model = c("michaelis-menten", "lomolino", "asymptotic", "weibull", "logistic", "evt"),
...
)
object |
A |
model |
Character. Model to fit: |
... |
Additional arguments passed to |
An object of class spacc_fit containing:
asymptote |
Estimated total species richness |
asymptote_ci |
Confidence interval for asymptote |
model |
Model name |
fit |
The nls fit object |
aic |
AIC of the model |
Lomolino, M.V. (2000). Ecology's most general, yet protean pattern: the species-area relationship. Journal of Biogeography, 27, 17-26.
Flather, C.H. (1996). Fitting species-accumulation functions and assessing regional land use impacts on avian diversity. Journal of Biogeography, 23, 155-168.
Borda-de-Agua, L., Whittaker, R.J., Cardoso, P., et al. (2025). Extreme value theory explains the topography and scaling of the species-area relationship. Nature Communications, 16, 5346.
coords <- data.frame(x = runif(50), y = runif(50))
species <- matrix(rbinom(50 * 30, 1, 0.3), nrow = 50)
sac <- spacc(species, coords)
fit <- extrapolate(sac)
print(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.