jackknife: Jackknife Richness Estimator

View source: R/estimators.R

jackknifeR Documentation

Jackknife Richness Estimator

Description

First- or second-order jackknife estimator of total species richness (Burnham & Overton 1978, 1979).

Usage

jackknife(x, order = 1L)

Arguments

x

A site-by-species matrix (presence/absence or abundance). Automatically binarized.

order

Integer. Jackknife order: 1 (default) or 2.

Details

First-order jackknife:

S_{jack1} = S_{obs} + Q_1 \frac{n-1}{n}

Second-order jackknife:

S_{jack2} = S_{obs} + \frac{Q_1(2n-3)}{n} - \frac{Q_2(n-2)^2}{n(n-1)}

Value

An object of class spacc_estimate.

References

Burnham, K.P. & Overton, W.S. (1978). Estimation of the size of a closed population when capture probabilities vary among animals. Biometrika, 65, 625-633.

Burnham, K.P. & Overton, W.S. (1979). Robust estimation of population size when capture probabilities vary among animals. Ecology, 60, 927-936.

See Also

chao2(), bootstrap_richness()

Examples

species <- matrix(rbinom(50 * 30, 1, 0.3), nrow = 50)
jackknife(species, order = 1)
jackknife(species, order = 2)


spacc documentation built on June 20, 2026, 5:07 p.m.