| chao1 | R Documentation |
Estimate total species richness from abundance data using the Chao1 estimator (Chao 1984). Uses the number of singletons and doubletons to estimate undetected species.
chao1(x)
x |
A site-by-species matrix (abundance data). Columns are pooled across sites. |
The Chao1 estimator is:
S_{Chao1} = S_{obs} + \frac{f_1^2}{2 f_2}
where f_1 is the number of singletons (species with total abundance 1)
and f_2 is the number of doubletons (abundance 2).
When f_2 = 0, the bias-corrected form is used:
S_{Chao1} = S_{obs} + \frac{f_1 (f_1 - 1)}{2}
An object of class spacc_estimate with components:
Name of the estimator ("chao1")
Estimated total richness
Standard error of the estimate
Lower 95 percent confidence bound
Upper 95 percent confidence bound
Observed species richness
List with f1 (singletons) and f2 (doubletons)
Chao, A. (1984). Nonparametric estimation of the number of classes in a population. Scandinavian Journal of Statistics, 11, 265-270.
Chao, A. (1987). Estimating the population size for capture-recapture data with unequal catchability. Biometrics, 43, 783-791.
chao2() for incidence-based estimation, ace() for
abundance-based coverage estimator
species <- matrix(rpois(50 * 30, 2), nrow = 50)
chao1(species)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.