| jackknife | R Documentation |
First- or second-order jackknife estimator of total species richness (Burnham & Overton 1978, 1979).
jackknife(x, order = 1L)
x |
A site-by-species matrix (presence/absence or abundance). Automatically binarized. |
order |
Integer. Jackknife order: 1 (default) or 2. |
First-order jackknife:
S_{jack1} = S_{obs} + Q_1 \frac{n-1}{n}
Second-order jackknife:
S_{jack2} = S_{obs} + \frac{Q_1(2n-3)}{n} - \frac{Q_2(n-2)^2}{n(n-1)}
An object of class spacc_estimate.
Burnham, K.P. & Overton, W.S. (1978). Estimation of the size of a closed population when capture probabilities vary among animals. Biometrika, 65, 625-633.
Burnham, K.P. & Overton, W.S. (1979). Robust estimation of population size when capture probabilities vary among animals. Ecology, 60, 927-936.
chao2(), bootstrap_richness()
species <- matrix(rbinom(50 * 30, 1, 0.3), nrow = 50)
jackknife(species, order = 1)
jackknife(species, order = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.